==> magento-magento2-base-2.1.13.zip: dev/tests/static/testsuite/Magento/Test/Legacy/LibraryLocationTest.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

/**
 * Verify that there are no files in the old locations of web and php libraries
 */
namespace Magento\Test\Legacy;

class LibraryLocationTest extends \PHPUnit_Framework_TestCase
{
    /**
     * Root path of Magento
     *
     * @var string
     */
    protected static $root;

    public static function setUpBeforeClass()
    {
        self::$root = BP;
    }

    public function testOldWebLibrariesLocation()
    {
        $oldLocation = self::$root . '/pub/lib';
        $this->assertFileNotExists($oldLocation, "The web libraries have been moved from 'pub/lib' to 'lib/web'");
    }

    public function testOldPhpLibrariesLocation()
    {
        $libLocation = self::$root . '/lib';

        $permittedEntries = [
            self::$root . '/lib/web',
            self::$root . '/lib/internal',
            self::$root . '/.htaccess',
        ];

        $entries = glob("{$libLocation}/*");
        $excessiveEntries = [];
        foreach ($entries as $entry) {
            $entry = str_replace('\\', '/', $entry);
            $permitted = false;
            foreach ($permittedEntries as $permittedEntry) {
                if ($permittedEntry == $entry) {
                    $permitted = true;
                    break;
                }
            }
            if (!$permitted) {
                $excessiveEntries[] = $entry;
            }
        }

        $this->assertEmpty(
            $excessiveEntries,
            "All files and directories have been moved from 'lib' to 'lib/internal'"
        );
    }
}

==> magento-magento2-base-2.4.1-p1.zip: dev/tests/static/testsuite/Magento/Test/Legacy/LibraryLocationTest.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

/**
 * Verify that there are no files in the old locations of web and php libraries
 */
namespace Magento\Test\Legacy;

class LibraryLocationTest extends \PHPUnit\Framework\TestCase
{
    /**
     * Root path of Magento
     *
     * @var string
     */
    protected static $root;

    public static function setUpBeforeClass(): void
    {
        self::$root = BP;
    }

    public function testOldWebLibrariesLocation()
    {
        $oldLocation = self::$root . '/pub/lib';
        $this->assertFileNotExists($oldLocation, "The web libraries have been moved from 'pub/lib' to 'lib/web'");
    }

    public function testOldPhpLibrariesLocation()
    {
        $libLocation = self::$root . '/lib';

        $permittedEntries = [
            self::$root . '/lib/web',
            self::$root . '/lib/internal',
            self::$root . '/.htaccess',
        ];

        $entries = glob("{$libLocation}/*");
        $excessiveEntries = [];
        foreach ($entries as $entry) {
            $entry = str_replace('\\', '/', $entry);
            $permitted = false;
            foreach ($permittedEntries as $permittedEntry) {
                if ($permittedEntry == $entry) {
                    $permitted = true;
                    break;
                }
            }
            if (!$permitted) {
                $excessiveEntries[] = $entry;
            }
        }

        $this->assertEmpty(
            $excessiveEntries,
            "All files and directories have been moved from 'lib' to 'lib/internal'"
        );
    }
}
